@@ -33,7 +33,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL.php,v 1.2 2006/12/11 12:00:31 seasonstream Exp $
+ * @version   CVS: $Id: SyL.php,v 1.3 2006/12/16 19:05:19 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -41,37 +41,14 @@
 /**
  * С
  */
-define('SYL_VERSION', '0.5.1');
+define('SYL_VERSION', '0.6.0');
 
 /**
  * ١ǥ쥯ȥ
  */
 define('SYL_DIR', dirname(__FILE__));
-define('SYL_CONFIG_DIR',  SYL_DIR . '/config');
 define('SYL_INCLUDE_DIR', SYL_DIR . '/include');
 
-/**
- * ƥ⥳ȥ̾
- */
-define('SYL_CONFIG_CONTROLLER_NAME', 'controller');
-
-/**
- * ե̾
- */
-define('SYL_CONFIG_DEFINE_FILE', 'defines.xml');
-/**
- * ݡͥե̾
- */
-define('SYL_CONFIG_COMPONENTS_FILE', 'components.xml');
-/**
- * ե륿ե̾
- */
-define('SYL_CONFIG_FILTERS_FILE', 'filters.xml');
-/**
- * ե̾
- */
-define('SYL_CONFIG_ACTIONS_FILE', 'actions.xml');
-
 /**
  * PHPƥ२顼¸ե饰
  */
@@ -84,12 +61,12 @@ define('SYL_CONFIG_SYSTEM_ERROR_LOG_FILE', SYL_DIR . '/resource/syslogs/phperror
 /**
  * ǥХå٥
  */
-define('SYL_LOG_NONE',    0);
-define('SYL_LOG_ERROR',   1); // = E_ERROR
-define('SYL_LOG_WARN',    2); // = E_WARNING
-define('SYL_LOG_NOTICE',  8); // = E_NOTICE
-define('SYL_LOG_INFO',   16);
-define('SYL_LOG_DEBUG',  32);
+define('SYL_LOG_NONE',     0);
+define('SYL_LOG_ERROR',    1); // = E_ERROR
+define('SYL_LOG_WARN',     2); // = E_WARNING
+define('SYL_LOG_NOTICE',   8); // = E_NOTICE
+define('SYL_LOG_INFO',  1024); // = E_USER_NOTICE 
+define('SYL_LOG_DEBUG', 8191); // = E_ALL
 
 
 /*
