@@ -27,16 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.5 2006/12/16 19:09:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * ե륯饹
- */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
-
 /**
  * եɤ߹९饹
  *
@@ -44,7 +39,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.5 2006/12/16 19:09:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -76,6 +71,13 @@ class SyL_ConfigActions extends SyL_Config
      * @var object
      */
     var $lc = null;
+    /**
+     * ݡͥȥ᥽åɥ֥
+     * 
+     * @access private
+     * @var object
+     */
+    var $cm = null;
 
     /**
      * 󥹥ȥ饯
@@ -98,9 +100,10 @@ class SyL_ConfigActions extends SyL_Config
      */
     function setController(&$controller)
     {
-        parent::setController($controller);
-        $this->router =& $controller->container->getComponent('router');
-        $this->lc      =& $controller->container->getComponent('locationmanager');
+        $this->controller =& $controller;
+        $this->router     =& $controller->container->getComponent('router');
+        $this->lc         =& $controller->container->getComponent('locationmanager');
+        $this->cm         =& $controller->container->getComponent('componentmethod');
     }
 
     /**
@@ -138,8 +141,8 @@ class SyL_ConfigActions extends SyL_Config
             }
 
             // URLǧ
-            $reg = isset($attribute['path']) ? $attribute['path'] : '(.*)';
-            if (preg_match('|^' . $reg . '$|', $this->router->getActionFile(), $matches)) {
+            $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
+            if (preg_match('/^' . $reg . '$/', $this->router->getActionFile(), $matches)) {
                 $name = $this->action_key;
                 $this->config[$name]['class']     = $this->router->getClassName();
                 $this->config[$name]['type']      = 'action';
@@ -215,7 +218,7 @@ class SyL_ConfigActions extends SyL_Config
                 $this->config[$component_name]['args'] = array();
 
                 // ץꥱ󥳥ݡͥ̾å
-                $this->lc->addAppComponent($component_name, '', $component_priority);
+                $this->cm->addAppComponent($component_name, '', $component_priority);
                 break;
 
             default:
@@ -272,7 +275,7 @@ class SyL_ConfigActions extends SyL_Config
 
                 case '/actions/action/components/component/final':
                     // ץꥱ󥳥ݡͥ̾å
-                    $this->lc->addAppComponent($component_name, $attribute['name'], $component_priority);
+                    $this->cm->addAppComponent($component_name, $attribute['name'], $component_priority);
                     break;
                 }
             }
