@@ -27,16 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.5 2006/12/16 19:09:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * ݒt@CNX
- */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
-
 /**
  * ݒt@Cǂݍ݁A萔NX
  *
@@ -44,7 +39,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.5 2006/12/16 19:09:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigDefines extends SyL_Config
