@@ -27,16 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.5 2006/12/16 19:09:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * 顼饹
- */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_Error.php';
-
 /**
  * WEB̥顼ɽ饹
  *
@@ -58,23 +53,11 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Error.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.5 2006/12/16 19:09:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
 {
-    /**
-     * Ǥ̥顼̤ɽ
-     * 
-     * @access public
-     * @param string 顼å
-     * @param int 顼٥
-     */
-    function trigger($error_string='', $error_type=E_USER_ERROR)
-    {
-        trigger_error($error_string, $error_type);
-    }
-
     /**
      * 顼ϥɥ顼μ
      * 
@@ -107,16 +90,16 @@ class SyL_ErrorWeb extends SyL_Error
             $error_trace = $this->getTraceHtml();
 
             // 顼ɽȽ
-            $router_type = '';
+            $error_View_type = '';
             switch (strtolower(SYL_ERROR_FORWARD_TYPE)) {
-            case 'template': $router_type = 'Template'; break;
-            case 'redirect': $router_type = 'Redirect'; break;
-            default:         $router_type = 'Default';  break;
+            case 'template': $error_View_type = 'Template'; break;
+            case 'redirect': $error_View_type = 'Redirect'; break;
+            default:         $error_View_type = 'Default';  break;
             }
 
             // 顼ɽ
-            $func_name = 'displayError' . $router_type;
-            call_user_func( array(&$this, $func_name), $error_type, $error_message, $error_trace);
+            $func_name = "displayError{$error_View_type}";
+            call_user_func(array(&$this, $func_name), $error_type, $error_message, $error_trace);
             // 
             $this->logging($error_no, $error_message);
 
@@ -137,7 +120,7 @@ class SyL_ErrorWeb extends SyL_Error
      */
     function displayErrorDefault($error_type, $error_message, $error_trace)
     {
-        echo "[" . $error_type . "] " . $error_message;
+        echo "[{$error_type}] {$error_message}";
         if (SYL_ERROR_TRACE) {
             echo "<br><br>";
             echo $error_trace;
@@ -155,22 +138,15 @@ class SyL_ErrorWeb extends SyL_Error
     function displayErrorTemplate($error_type, $error_message, $error_trace)
     {
         // 顼å
-        $error_string = "[" . $error_type . "] " . $error_message;
-        $include_file = '';
-        if (is_file(SYL_WEBAPP_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
-            $include_file = SYL_WEBAPP_DIR . '/' . SYL_ERROR_FORWARD_FILE;
-        } else if (is_file(SYL_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
-            $include_file = SYL_DIR . '/' . SYL_ERROR_FORWARD_FILE;
-        } else if (is_file(SYL_ERROR_FORWARD_FILE)) {
-            $include_file = SYL_ERROR_FORWARD_FILE;
+        $error_string = "[{$error_type}] {$error_message}";
+        if (is_file(SYL_WEBAPP_LIB_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
+            // 顼ƥץ졼ɤ߹
+            // $error_string
+            // $error_trace
+            include_once SYL_WEBAPP_LIB_DIR . '/' . SYL_ERROR_FORWARD_FILE;
         } else {
-            trigger_error("[SyL error] error template not found (" . SYL_ERROR_FORWARD_FILE . ")", E_USER_ERROR);
+            trigger_error("[SyL error] error template not found (" . SYL_WEBAPP_LIB_DIR . '/' . SYL_ERROR_FORWARD_FILE . ")", E_USER_ERROR);
         }
-
-        // 顼ƥץ졼ɤ߹
-        // $error_string
-        // $error_trace
-        include_once $include_file;
     }
 
     /**
