@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameter.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameter.php,v 1.5 2006/12/16 19:10:17 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameter.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameter.php,v 1.5 2006/12/16 19:10:17 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestParameter extends SyL_Request
@@ -67,7 +67,7 @@ class SyL_RequestParameter extends SyL_Request
 
         // ޥåݥȤͭȽ
         if (get_magic_quotes_gpc()) {
-            $this->applyParametersRecursive($this->parameters, 'stripslashes');
+            $this->applyParameters('stripslashes');
         }
     }
 }
