@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -147,24 +147,13 @@ echo "</pre>";
                 if (!isset($keys['event'][$event]) || !in_array($name, $keys['event'][$event])) {
                     continue;
                 }
-
-                if (is_file(SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'])) {
-                    // SyLǥ쥯ȥ꤫Υѥ
-                    include_once SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'];
-                } else if (is_file(SYL_WEBAPP_DIR . DIRECTORY_SEPARATOR . $keys['file'])) {
-                    // ץꥱǥ쥯ȥ꤫Υѥ
-                    include_once SYL_WEBAPP_DIR . DIRECTORY_SEPARATOR . $keys['file'];
-                } else if (is_file($keys['file'])) {
-                    // եѥ
-                    include_once $keys['file'];
-                } else {
-                    // ݡͥȥե뤬̵
-                    $this->log('info', "Component include failed: file not found ({$keys['file']} or " . SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'] . " or " . SYL_APP_DIR . DIRECTORY_SEPARATOR . $keys['file'] . ")");
+                // ݡͥȤ
+                if (!$this->LoadLib($keys['file'])) {
                     // ٥Ⱥ
                     $this->deleteEventConfig($name, $name, $event, $keys, $tmp_config);
                     continue;
                 }
-
+                // 饹Ƚ
                 if (!class_exists($classname)) {
                     // 饹̵
                     trigger_error("[SyL error] Component class not found (class name: {$classname})", E_USER_ERROR);
@@ -248,17 +237,15 @@ echo "</pre>";
                 $funcs = explode(':', $func);
                 switch (strtolower($funcs[0])) {
                 case 'constructor':
-                    $ref = $keys['reference'] ? '&' : '';
-                    if (is_file(SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'])) {
-                        include_once SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'];
+                    // ݡͥȤ
+                    if ($this->LoadLib($keys['file'])) {
+                        $ref = $keys['reference'] ? '&' : '';
                         if ($funcs[1] != '') {
                             eval('$component =' . $ref . ' ' . $classname  . '::' . $funcs[1] . '(' . $eval_args . ');');
                         } else {
                             eval('$component =' . $ref . ' new ' . $classname . '(' . $eval_args . ');' ); 
                         }
                         $this->setComponent($name, $component);
-                    } else {
-                        $this->log('info', "Component or Action or Filter include failed: file not found ({$keys['file']} or " . SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'] . ")");
                     }
                     break;
 
@@ -307,6 +294,10 @@ echo "</pre>";
         foreach ($config_type as $type => $file) {
             $files = explode(PATH_SEPARATOR, $file);
             foreach ($files as $f) {
+                if (!is_file($f)) {
+                    // ե뤬̵
+                    trigger_error("[SyL error] Config file not found (file name: {$f})", E_USER_ERROR);
+                }
                 $config += $this->getConfig($event, $type, $f);
             }
         }
@@ -346,6 +337,32 @@ echo "</pre>";
         return strcmp($current['priority'], $next['priority']);
     }
 
+    /**
+     * 饤֥
+     *
+     * @access public
+     * @param string ɥե
+     * @return bool true: OK, false, NG
+     */
+    function LoadLib($file)
+    {
+        if (is_file(SYL_INCLUDE_DIR . "/{$file}")) {
+            // SyLǥ쥯ȥ꤫Υѥ
+            include_once SYL_INCLUDE_DIR . "/{$file}";
+        } else if (is_file(SYL_WEBAPP_LIB_DIR . "/{$file}")) {
+            // ץꥱǥ쥯ȥ꤫Υѥ
+            include_once SYL_WEBAPP_LIB_DIR . "/{$file}";
+        } else if (is_file($file)) {
+            // եѥ
+            include_once $file;
+        } else {
+            // ݡͥȥե뤬̵
+            $this->log('info', "Component include failed: file not found (" . SYL_INCLUDE_DIR . "/{$file} or " . SYL_WEBAPP_LIB_DIR . "/{$file} or {$file})");
+            return false;
+        }
+        return true;
+    }
+
     /**
      * ٥
      *
