@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -43,16 +43,11 @@ set_magic_quotes_runtime(0);
 /**
  * PHPƥ२顼¸
  */
-if (SYL_CONFIG_SYSTEM_ERROR_LOG) {
+if (SYL_CONFIG_SYSTEM_ERROR_LOG && is_writable(dirname(SYL_CONFIG_SYSTEM_ERROR_LOG_FILE))) {
     ini_set('log_errors', SYL_CONFIG_SYSTEM_ERROR_LOG);
     ini_set('error_log', SYL_CONFIG_SYSTEM_ERROR_LOG_FILE);
 }
 
-/**
- * 饤֥ǥ쥯ȥΥ󥯥롼ɥѥå
- */
-//set_include_path(get_include_path() . PATH_SEPARATOR . SYL_INCLUDE_DIR);
-
 /**
  * եɤ߹९饹
  */
@@ -62,6 +57,11 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_DefinesReader.php';
  */
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Container.php';
 
+/**
+ * ƥ⥳ȥ̾
+ */
+define('SYL_CONFIG_CONTROLLER_NAME', 'controller');
+
 /**
  * ȥ饯饹
  *
@@ -69,33 +69,16 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Container.php';
  * Ƥ
  *   DIƥʤݻ
  *   ήȼܥ٥Ƚ
- * 
- * ++ ܥ٥
- *   1. initStream         - ȥ顼Υ󥹥ȥ饯¹Ը
- *   2.   loadStream       - ¹
- *   3.     executeStream  - ¹
- *   4.       middleStream - ¹Ը塢ӥ塼ɽ¹
- *   5.     renderStream   - ӥ塼ɽ¹
- *   6.   unloadStream     - ӥ塼ɽ¹Ը
- *   7. finalStream        - shutdown
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
 {
-    /**
-     * ץꥱ̾
-     * webapp/(ץꥱ̾)/...
-     *
-     * @access public
-     * @var string
-     */
-    var $app_name = '';
     /**
      * ǥ쥯ȥ롼
      *
@@ -111,12 +94,19 @@ class SyL_Controller
      */
     var $template_dir = '';
     /**
-     * ¹Ƚ
-     * 
+     * ե̾
+     *
      * @access private
-     * @var bool
+     * @var string
      */
-    var $is_execute_action = true;
+    var $defines_file_name = 'defines.xml';
+    /**
+     * ݡͥե̾
+     *
+     * @access protected
+     * @var string
+     */
+    var $components_file_name = 'components.xml';
     /**
      * ƥʥ֥
      *
@@ -140,6 +130,31 @@ class SyL_Controller
      */
     var $destory_objects = array();
 
+    /**
+     * ȥ
+     *
+     * ¹ԴĶˤꡢWEB or CmdΥȥȽꤷƼ
+     *
+     * @access public
+     * @param array Ķ
+     */
+    function &getController($config)
+    {
+        static $singleton;
+        if (!is_object($singleton)) {
+            if ((PHP_SAPI == 'cli') || ((PHP_SAPI == 'cgi') && !isset($_SERVER['REQUEST_METHOD']))) {
+                define('SYL_ENV_TYPE', 'cmd');
+            } else {
+                define('SYL_ENV_TYPE', 'web');
+            }
+            $class_name = 'SyL_Controller' . ucfirst(SYL_ENV_TYPE);
+            include_once SYL_INCLUDE_DIR . "/framework/Controller/{$class_name}.php";
+            // ҥ饹Υ󥹥
+            $singleton = new $class_name($config);
+        }
+        return $singleton;
+    }
+
     /**
      * 󥹥ȥ饯
      *
@@ -149,29 +164,27 @@ class SyL_Controller
     function SyL_Controller($config)
     {
         // ץꥱ̾
-        if (isset($config['app_name']) && $config['app_name']) {
-            $this->app_name = $config['app_name'];
-        } else {
+        if (!isset($config['app_name']) || !$config['app_name']) {
             trigger_error("[SyL error] Controller parameter app_name not exists", E_USER_ERROR);
         }
 
-        // 󥭡
-        if (isset($config['action_key']) && $config['action_key']) {
-            define('SYL_ACTION_KEY', $config['action_key']);
-        } else {
-            trigger_error("[SyL error] Controller parameter action_key not exists", E_USER_ERROR);
-        }
-
-        // å
-        define('SYL_CACHE_DIR', (isset($config['cache_dir']) && $config['cache_dir']) ? $config['cache_dir'] : false);
         // ǥХå٥
         define('SYL_DEBUG', (isset($config['debug']) && is_numeric($config['debug'])) ? $config['debug'] : SYL_LOG_NOTICE);
         // WEBץꥱǥ쥯ȥ
         define('SYL_WEBAPP_DIR', (isset($config['webapp_dir']) && $config['webapp_dir']) ? $config['webapp_dir'] : SYL_DIR . '/webapp');
+        // å
+        define('SYL_WEBAPP_CACHE_DIR', (isset($config['cache_dir']) && $config['cache_dir']) ? SYL_WEBAPP_DIR . $config['cache_dir'] : false);
+        // WEBץꥱեǥ쥯ȥ
+        define('SYL_WEBAPP_CONFIG_DIR',  SYL_WEBAPP_DIR . '/config');
+        // WEBץꥱ饤֥ǥ쥯ȥ
+        define('SYL_WEBAPP_LIB_DIR',  SYL_WEBAPP_DIR . '/lib');
         // ץꥱǥ쥯ȥ
-        define('SYL_APP_DIR', SYL_WEBAPP_DIR . '/' . $this->app_name);
+        define('SYL_APP_DIR', SYL_WEBAPP_DIR . '/app/' . $config['app_name']);
 
-        // shutdown᥽å
+        // ɤ߹
+        SyL_DefinesReader::readConfig($this, $this->defines_file_name);
+
+        // shutdownϥɥ
         if ($this->destory_method != '') {
             register_shutdown_function(array(&$this, $this->destory_method));
         }
@@ -181,9 +194,6 @@ class SyL_Controller
         // ƥץ졼ȥǥ쥯ȥ
         $this->template_dir = SYL_APP_DIR . '/templates';
 
-        // ɤ߹
-        SyL_DefinesReader::readConfig($this);
-
         // ƥ
         $this->container =& new SyL_Container();
         $this->container->setComponent(SYL_CONFIG_CONTROLLER_NAME, $this);
@@ -196,12 +206,8 @@ class SyL_Controller
      */
     function initStream()
     {
-        // Х륳ݡͥե
-        $config_file = array(
-          'components' => SYL_CONFIG_DIR . '/' . SYL_CONFIG_COMPONENTS_FILE
-        );
         // ٥ȼ¹
-        $this->raiseEvent('initStream', $config_file);
+        $this->raiseEvent('initStream');
     }
 
     /**
@@ -211,16 +217,8 @@ class SyL_Controller
      */
     function loadStream()
     {
-        // Хե륿ե
-        $global_filters_file = SYL_CONFIG_DIR . '/' . SYL_CONFIG_FILTERS_FILE;
-        // ץꥱե륿ե
-        $app_filters_file = SYL_APP_DIR . '/' . SYL_CONFIG_FILTERS_FILE;
-
-        $config_file = array();
-        $config_file['filters'] = $global_filters_file . PATH_SEPARATOR . $app_filters_file;
-
         // ٥ȼ¹
-        $this->raiseEvent('loadStream', $config_file);
+        $this->raiseEvent('loadStream');
     }
 
     /**
@@ -230,16 +228,8 @@ class SyL_Controller
      */
     function executeStream()
     {
-        // ¹Ƚ
-        $config_file = array();
-        if ($this->isExecuteAction()) {
-            // ե
-            $app_actions_file = SYL_APP_DIR . '/' . SYL_CONFIG_ACTIONS_FILE;
-            $config_file['actions'] = $app_actions_file;
-        }
-
         // ٥ȼ¹
-        $this->raiseEvent('executeStream', $config_file);
+        $this->raiseEvent('executeStream');
     }
 
     /**
@@ -283,17 +273,10 @@ class SyL_Controller
      */
     function finalStream()
     {
-        // ¹ԥ
+        // ٥ȼ¹
         if (is_object($this->container)) {
-            // ٥ȼ¹
             $this->raiseEvent('finalStream');
         }
-
-        // ݡͥȤȤϿ줿destory᥽åɼ¹
-        $cnt = count($this->destory_objects);
-        for ($i=0; $i<$cnt; $i++) {
-          call_user_func($this->destory_objects[$i]);
-        }
     }
 
     /**
@@ -303,31 +286,12 @@ class SyL_Controller
      */
     function stream()
     {
-        // 
-        $this->initStream();
-        // ¹
-        $this->loadStream();
-        // ¹Խ
-        $this->executeStream();
-        // ӥ塼ɽ¹
-        $this->middleStream();
-        // ӥ塼ɽ¹
-        $this->renderStream();
-        // ӥ塼ɽ¹Ը
-        $this->unloadStream();
-/*
-echo "<pre>";
-print_r($this->container->components);
-echo "</pre>";
-
-*/
-
     }
 
     /**
      * ٥ȼ¹
      *
-     * @access private
+     * @access protected
      * @param string ٥ȥ᥽å̾
      * @param string ե̾
      */
@@ -346,39 +310,6 @@ echo "</pre>";
     {
         return $this->action_dir;
     }
-
-    /**
-     * ƥץ졼ȥǥ쥯ȥ
-     *
-     * @access public
-     * @return string ƥץ졼ȥǥ쥯ȥ
-     */
-    function getTemplateDir()
-    {
-        return $this->template_dir;
-    }
-
-    /**
-     * ¹Ƚ򥻥å
-     * 
-     * @access public
-     * @return bool true: ¹Ԥ롢false: ¹Ԥʤ
-     */
-    function setExecuteAction($is_execute_action)
-    {
-        $this->is_execute_action = ($is_execute_action !== false);
-    }
-
-    /**
-     * ¹Ƚ
-     * 
-     * @access public
-     * @return bool true: ¹Ԥ롢false: ¹Ԥʤ
-     */
-    function isExecuteAction()
-    {
-        return $this->is_execute_action;
-    }
 }
 
 ?>
