@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loggers.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -81,16 +81,16 @@ class SyL_Error
      * @access public
      * @param string 顼
      */
-    function &getInstance($type='Web')
+    function &getInstance()
     {
         static $singleton;
         if (!is_object($singleton)) {
-            $e = 'SyL_Error' . ucfirst($type);
-            include_once SYL_INCLUDE_DIR . "/framework/Error/{$e}.php";
+            $class_name = 'SyL_Error' . ucfirst(SYL_ENV_TYPE);
+            include_once SYL_INCLUDE_DIR . "/framework/Error/{$class_name}.php";
             // ҥ饹Υ󥹥
-            $singleton = new $e();
+            $singleton = new $class_name();
             // 顼ϥɥ饻å
-            $singleton->setErrorHandler();
+            call_user_func(array($singleton, 'setErrorHandler'));
         }
         return $singleton;
     }
@@ -98,6 +98,7 @@ class SyL_Error
     /**
      * 顼å򥻥å
      * 
+     * @static
      * @access public
      * @param string 顼å
      */
@@ -110,17 +111,20 @@ class SyL_Error
     /**
      * Ǥ̥顼̤ɽ
      * 
+     * @static
      * @access public
      * @param string 顼å
      * @param int 顼٥
      */
     function trigger($error_string='', $error_type=E_USER_ERROR)
     {
+        trigger_error($error_string, $error_type);
     }
 
     /**
      * 顼ϥɥ
      * 
+     * @static
      * @access public
      */
     function setErrorHandler()
@@ -132,6 +136,7 @@ class SyL_Error
     /**
      * 顼ϥɥ
      * 
+     * @static
      * @access public
      */
     function resetErrorHandler()
