@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loggers.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loggers.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,22 +44,30 @@ require_once 'SyL_Logger.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loggers.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loggers.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Loggers
 {
     /**
-     * ƥꥪ֥ȳǼ
+     * ¸ե饰
      * 
      * @access public
+     * @var bool
+     */
+    var $log = SYL_LOG;
+
+    /**
+     * ƥꥪ֥ȳǼ
+     * 
+     * @access private
      * @var array
      */
     var $loggers = array();
     /**
      * ٥Ǽ
      * 
-     * @access public
+     * @access private
      * @var array
      */
     var $modes = array();
@@ -106,9 +114,11 @@ class SyL_Loggers
     function error($message)
     {
         $log =& SyL_Loggers::getInstance();
-        foreach (array_keys($log->loggers) as $key) {
-            if ($log->modes[$key] >= SYL_LOG_ERROR) {
-                $log->loggers[$key]->log('error', $message);
+        if ($log->log) {
+            foreach (array_keys($log->loggers) as $key) {
+                if ($log->modes[$key] >= SYL_LOG_ERROR) {
+                    $log->loggers[$key]->log('error', $message);
+                }
             }
         }
     }
@@ -122,9 +132,29 @@ class SyL_Loggers
   function warn($message)
   {
         $log =& SyL_Loggers::getInstance();
-        foreach (array_keys($log->loggers) as $key) {
-            if ($log->modes[$key] >= SYL_LOG_WARN) {
-                $log->loggers[$key]->log('warn', $message);
+        if ($log->log) {
+            foreach (array_keys($log->loggers) as $key) {
+                if ($log->modes[$key] >= SYL_LOG_WARN) {
+                    $log->loggers[$key]->log('warn', $message);
+                }
+            }
+        }
+    }
+
+  /**
+   * νϡNOTICE
+   *
+   * @access public
+   * @param string å
+   */
+  function notice($message)
+  {
+        $log =& SyL_Loggers::getInstance();
+        if ($log->log) {
+            foreach (array_keys($log->loggers) as $key) {
+                if ($log->modes[$key] >= SYL_LOG_NOTICE) {
+                    $log->loggers[$key]->log('warn', $message);
+                }
             }
         }
     }
@@ -138,9 +168,11 @@ class SyL_Loggers
     function info($message)
     {
         $log =& SyL_Loggers::getInstance();
-        foreach (array_keys($log->loggers) as $key) {
-            if ($log->modes[$key] >= SYL_LOG_INFO) {
-                $log->loggers[$key]->log('info', $message);
+        if ($log->log) {
+            foreach (array_keys($log->loggers) as $key) {
+                if ($log->modes[$key] >= SYL_LOG_INFO) {
+                    $log->loggers[$key]->log('info', $message);
+                }
             }
         }
     }
@@ -154,9 +186,11 @@ class SyL_Loggers
     function debug($message)
     {
         $log =& SyL_Loggers::getInstance();
-        foreach (array_keys($log->loggers) as $key) {
-            if ($log->modes[$key] >= SYL_LOG_DEBUG) {
-                $log->loggers[$key]->log('debug', $message);
+        if ($log->log) {
+            foreach (array_keys($log->loggers) as $key) {
+                if ($log->modes[$key] >= SYL_LOG_DEBUG) {
+                    $log->loggers[$key]->log('debug', $message);
+                }
             }
         }
     }
