@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.2 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.3 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.2 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.3 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -201,7 +201,7 @@ class SyL_Router
             header('Location: ' . SYL_ROUTER_URL_404);
             exit;
         } else {
-            exit("HTTP/1.0 404 Not Found");
+            exit("<h2>HTTP/1.0 404 Not Found</h2>");
         }
     }
 
