@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.5 2006/12/16 19:07:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -51,14 +51,23 @@ class SyL_View
      * @var object
      */
     var $lm = null;
+    /**
+     * ݡͥȥ᥽åɥ֥
+     * 
+     * @access protected
+     * @var object
+     */
+    var $cm = null;
 
     /**
      * 󥹥ȥ饯
      *
      * @access public
      */
-    function SyL_View()
+    function SyL_View(&$lm, &$cm)
     {
+        $this->lm =& $lm;
+        $this->cm =& $cm;
     }
 
     /**
@@ -68,17 +77,16 @@ class SyL_View
      * @param object ӥ塼ǡ֥
      * @return object ӥ塼֥
      */
-    function &create(&$lm)
+    function &create(&$lm, &$cm)
     {
-        $class_name      = '';
-        $template_object = null;
-        $template_object =& new SyL_View();
+        $class_name = '';
+        $template   = null;
         $type = $lm->getTemplateType();
         if (strtolower($type) == 'customize') {
             $class_name = $lm->getCustomizedViewClass();
             $class_file = $lm->getCustomizedViewFile();
             if (!is_file($class_file)) {
-                $class_file1 = SYL_WEBAPP_DIR . DIRECTORY_SEPARATOR . $class_file;
+                $class_file1 = SYL_WEBAPP_LIB_DIR . "/{$class_file}";
                 if (!is_file($class_file1)) {
                     trigger_error("[SyL error] Customised View file not found ({$class_file} or {$class_file1})", E_USER_ERROR);
                 }
@@ -89,9 +97,8 @@ class SyL_View
             $class_name = 'SyL_View' . ucfirst($type);
             include_once(SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php");
         }
-        $template_object =& new $class_name();
-        $template_object->lm =& $lm;
-        return $template_object;
+        $template =& new $class_name($lm, $cm);
+        return $template;
     }
 
     /**
