@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.5 2006/12/16 19:08:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.4 2006/12/11 11:59:42 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.5 2006/12/16 19:08:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewSmarty extends SyL_View
@@ -65,8 +65,10 @@ class SyL_ViewSmarty extends SyL_View
      *
      * @access public
      */
-    function SyL_ViewSmarty()
+    function SyL_ViewSmarty(&$lm, &$cm)
     {
+        parent::SyL_View($lm, $cm);
+
         $this->smarty =& new Smarty();
         $this->smarty->compile_dir = SYL_SMARTY_COMPILE_DIR;
         $this->smarty->config_dir  = SYL_SMARTY_CONFIG_DIR;
