@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_CacheFileupdate.php,v 1.1 2006/12/11 11:59:19 seasonstream Exp $
+ * @version   CVS: $Id: SyL_CacheFileupdate.php,v 1.2 2006/12/16 19:07:28 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_CacheFileupdate.php,v 1.1 2006/12/11 11:59:19 seasonstream Exp $
+ * @version   CVS: $Id: SyL_CacheFileupdate.php,v 1.2 2006/12/16 19:07:28 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_CacheFileupdate extends SyL_Cache
@@ -79,6 +79,9 @@ class SyL_CacheFileupdate extends SyL_Cache
         $mtime = false;
         // ǿιդ
         foreach ($files as $file) {
+            if (!file_exists($file)) {
+                trigger_error("[SyL error] File not found for cache update ({$file})", E_USER_ERROR);
+            }
             $mtime_tmp = filemtime($file);
             if ($mtime) {
                 if ($mtime_tmp > $mtime) {
@@ -89,7 +92,8 @@ class SyL_CacheFileupdate extends SyL_Cache
             }
         }
 
-        if ($mtime && ($mtime <= $this->getModifyTime())) {
+        $cache_mtime = $this->getModifyTime();
+        if ($mtime && $cache_mtime && ($mtime <= $cache_mtime)) {
             // å
             return parent::read(false);
         } else {
