@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB_Ibsql.php,v 1.4 2006/12/11 11:59:19 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB_Ibsql.php,v 1.5 2006/12/16 19:07:28 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -41,11 +41,31 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB_Ibsql.php,v 1.4 2006/12/11 11:59:19 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB_Ibsql.php,v 1.5 2006/12/16 19:07:28 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB_Ibsql extends SyL_DB
 {
+    /**
+     * 󥳡Ѵơ֥
+     *
+     *  Firebird <=> PHP
+     *  (client)     (client)
+     * 
+     * ƾʸǵ
+     *
+     * @access protected
+     * @var string
+     */
+    var $encode_table = array(
+      // PHP, DB
+      array('eucjp-win', 'eucj_0208'),
+      array('euc-jp',    'eucj_0208'),
+      array('sjis-win',  'sjis_0208' ),
+      array('sjis',      'sjis_0208'),
+      array('utf-8',     'unicode_fss')
+    );
+
     /**
      * ȥ󥶥ID
      * 
@@ -71,6 +91,10 @@ class SyL_DB_Ibsql extends SyL_DB
         if ($host != '') {
             $dbname = $host . ':' . $dbname;
         }
+
+        // ³Υ󥳡
+        parent::setClientEncoding();
+
         if ($this->client_encode != '') {
             $this->connection = ($persistent) ? ibase_pconnect($dbname, $user, $passwd, $this->client_encode) : ibase_connect($dbname, $user, $passwd, $this->client_encode);
         } else {
@@ -107,166 +131,12 @@ class SyL_DB_Ibsql extends SyL_DB
      * ѥ᡼˥̵˽
      * 
      * @access public
-     *
      * @param string ˥оʸ
      * @return string ˥ʸ
      */
     function sanitize($parameter)
     {
-        return (!is_numeric($parameter) ? str_replace("'", "''", $parameter) : $parameter);
-    }
-
-    /**
-     * SQL¹ԤDB꥽
-     *
-     * @access public
-     * @param string SQLʸ
-     * @return mixed ¹OK: DB꥽, ¹NG: false
-     */
-    function executeSelect( $sql )
-    {
-        $result = @ibase_query($this->connection, $sql);
-        if ($result !== false) {
-            return $result;
-        } else {
-            $this->trigger_error_db($this->getLastError());
-            return false;
-        }
-    }
-
-    /**
-     * *** SQL¹Ͼtrue֤ ***
-     *
-     * SQL¹Ԥ¹Է̱ƶ
-     *
-     * @access public
-     * @param string SQLʸ
-     * @return mixed ¹OK: ¹Է̱ƶ, ¹NG: false
-     */
-    function executeUpdate( $sql )
-    {
-        // ¹Ի顼Ƚ
-        $result = @ibase_query($this->connection, $sql);
-        if ($result !== false) {
-            return $result;
-        } else {
-            $this->trigger_error_db($this->getLastError());
-            return false;
-        }
-    }
-
-    /**
-     * SQL¹ԤΤ
-     *
-     * @access public
-     *
-     * @param string SQLʸ
-     * @return boolean ¹OK: true, ¹NG: false
-     */
-    function executeNoReturn( $sql )
-    {
-        // ¹Ի顼Ƚ
-        $result = @ibase_query($this->connection, $sql);
-        if ($result !== false) {
-            return $result;
-        } else {
-            $this->trigger_error_db($this->getLastError());
-            return false;
-        }
-    }
-
-    /**
-     * SQL¹Ԥ̥ǡ
-     *
-     * 3ѥ᡼'one'ξ
-     *    ǽ1ʸȤƼ
-     * 3ѥ᡼'record'ξ
-     *    ǽ1쥳ɤȤƼ
-     * 3ѥ᡼'all'ξ
-     *    쥳ɤȤƼ
-     *
-     * @access public
-     * @param string SQLʸ
-     * @param mixed  ¹Է̤
-     * @param string ̼ե饰
-     * @return boolean ¹OK: true, ¹NG: false
-     */
-    function executeGet($sql, &$data, $get='all')
-    {
-        // SQL¸
-        $this->setLog( $sql );
-        // SQL¹
-        $query = @ibase_query($this->connection, $sql);
-
-        // ¹Ի顼Ƚ
-        if (is_resource($query)) {
-            switch ($get) {
-            // 1ե
-            case 'one':
-                list($data) = ibase_fetch_row($query);
-                if ($data === false) {
-                    $data = '';
-                }
-                break;
-            // 1쥳
-            case 'record':
-                $data = ibase_fetch_assoc($query);
-                if ($data === false) {
-                    $data = array();
-                } else {
-                    $data = $this->changeFieldName($data);
-                }
-                break;
-            // 쥳
-            case 'all':
-                $data = array();
-                while ($result = ibase_fetch_assoc($query)) {
-                  $data[] = $this->changeFieldName($result);
-                }
-              break;
-            }
-            ibase_free_result($query);
-            return true;
-        } else {
-            $this->trigger_error_db($this->getLastError());
-            return false;
-        }
-    }
-
-    /**
-     * SQL¹Ԥڡ˥ǡ
-     * ¹ˡinitializePageץ᥽åɼ¹ɬ
-     * SQLʸΡFROM׶ľ˥ʸɬܡʤʳΥʸԲġ
-     *
-     * @access public
-     * @param string SQLʸ
-     * @param array ¹Է̳Ǽ
-     * @param object ڡ֥
-     * @param int 1ڡɽ
-     * @param int ɽоݥڡ 
-     * @return bool ¹Է
-     */
-    function executePage($sql, &$result, &$page_control, $limit, $page=1)
-    {
-        // ڡ楯饹
-        include_once dirname(dirname(__FILE__)) . DIRECTORY_SEPARATOR . 'SyL_PageControl.php';
-        $page_control = new SyL_PageControl();
-        $page_control->setCount($limit);
-        $page_control->setPage($page);
-
-        // SQL
-        $sql_count = "SELECT COUNT(*) FROM (" . $sql . ") AS SyL$";
-        // SQL¹
-        if (!$this->executeGet($sql_count, $record, 'one')) return false;
-        $page_control->setCountAll($record);
-
-        // ڡñ̥쥳ɼ
-        $sql_page  = $sql;
-        if (preg_match('/^\s*(select)\s+(.+)$/i', $sql_page, $matches)) {
-            $sql_page = $matches[1] . ' first ' . $page_control->getCount() . ' skip ' . $page_control->getStartRecord() . ' ' . $matches[2];
-        }
-        // ǡSQL¹
-        return $this->executeGet($sql_page, $result, 'all');
+        return !is_numeric($parameter) ? str_replace("'", "''", $parameter) : $parameter;
     }
 
     /**
@@ -304,6 +174,156 @@ class SyL_DB_Ibsql extends SyL_DB
         parent::commit();
     }
 
+    /**
+     * SQL¹ԤDB꥽
+     *
+     * @access public
+     * @param string SQLʸ
+     * @return mixed ¹OK: DB꥽, ¹NG: false
+     */
+    function executeSelect($sql)
+    {
+        $result = @ibase_query($this->connection, $sql);
+        if ($result !== false) {
+            return $result;
+        } else {
+            $this->executeTriggerError($this->getLastError());
+            return false;
+        }
+    }
+
+    /**
+     * *** SQL¹Ͼtrue֤ ***
+     *
+     * SQL¹Ԥ¹Է̱ƶ
+     *
+     * @access public
+     * @param string SQLʸ
+     * @return mixed ¹OK: ¹Է̱ƶ, ¹NG: false
+     */
+    function executeUpdate($sql)
+    {
+        // ¹Ի顼Ƚ
+        $result = @ibase_query($this->connection, $sql);
+        if ($result !== false) {
+            return $result;
+        } else {
+            $this->executeTriggerError($this->getLastError());
+            return false;
+        }
+    }
+
+    /**
+     * SQL¹ԤΤ
+     *
+     * @access public
+     * @param string SQLʸ
+     * @return boolean ¹OK: true, ¹NG: false
+     */
+    function executeNoReturn($sql)
+    {
+        // ¹Ի顼Ƚ
+        $result = @ibase_query($this->connection, $sql);
+        if ($result !== false) {
+            return $result;
+        } else {
+            $this->executeTriggerError($this->getLastError());
+            return false;
+        }
+    }
+
+    /**
+     * SQL¹Ԥ̥ǡ
+     *
+     * 3ѥ᡼'one'ξ
+     *    ǽ1ʸȤƼ
+     * 3ѥ᡼'record'ξ
+     *    ǽ1쥳ɤȤƼ
+     * 3ѥ᡼'all'ξ
+     *    쥳ɤȤƼ
+     *
+     * @access public
+     * @param string SQLʸ
+     * @param mixed  ¹Է̤
+     * @param string ̼ե饰
+     * @return boolean ¹OK: true, ¹NG: false
+     */
+    function executeGet($sql, &$data, $get='all')
+    {
+        // SQL¹
+        $this->execute($sql, $query);
+
+        // ¹Ի顼Ƚ
+        if (is_resource($query)) {
+            switch ($get) {
+            // 1ե
+            case 'one':
+                list($data) = ibase_fetch_row($query);
+                if ($data === false) {
+                    $data = '';
+                }
+                break;
+            // 1쥳
+            case 'record':
+                $data = ibase_fetch_assoc($query);
+                if ($data === false) {
+                    $data = array();
+                } else {
+                    $data = $this->changeFieldName($data);
+                }
+                break;
+            // 쥳
+            case 'all':
+                $data = array();
+                while ($result = ibase_fetch_assoc($query)) {
+                  $data[] = $this->changeFieldName($result);
+                }
+              break;
+            }
+            ibase_free_result($query);
+            return true;
+        } else {
+            $this->executeTriggerError($this->getLastError());
+            return false;
+        }
+    }
+
+    /**
+     * SQL¹Ԥڡ˥ǡ
+     * ¹ˡinitializePageץ᥽åɼ¹ɬ
+     * SQLʸΡFROM׶ľ˥ʸɬܡʤʳΥʸԲġ
+     *
+     * @access public
+     * @param string SQLʸ
+     * @param array ¹Է̳Ǽ
+     * @param object ڡ֥
+     * @param int 1ڡɽ
+     * @param int ɽоݥڡ 
+     * @return bool ¹Է
+     */
+    function executePage($sql, &$result, &$page_control, $limit, $page=1)
+    {
+        // ڡ楯饹
+        include_once dirname(dirname(__FILE__)) . '/SyL_Pager.php';
+        $page_control = new SyL_Pager();
+        $page_control->setCount($limit);
+        $page_control->setPage($page);
+
+        // SQL
+        $sql_count = "SELECT COUNT(*) FROM (" . $sql . ") AS SyL$";
+        // SQL¹
+        if (!$this->executeGet($sql_count, $record, 'one')) return false;
+        $page_control->setCountAll($record);
+
+        // ڡñ̥쥳ɼ
+        $sql_page  = $sql;
+        if (preg_match('/^(select)\s+(.+)$/i', trim($sql_page), $matches)) {
+            $sql_page = $matches[1] . ' first ' . $page_control->getCount() . ' skip ' . $page_control->getStartRecord() . ' ' . $matches[2];
+        }
+        // ǡSQL¹
+        return $this->executeGet($sql_page, $result, 'all');
+    }
+
     /**
      * եեޥåȴؿ̾
      *
