@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB_Mysql.php,v 1.4 2006/12/11 11:59:19 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB_Mysql.php,v 1.5 2006/12/16 19:07:28 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -41,11 +41,31 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB_Mysql.php,v 1.4 2006/12/11 11:59:19 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB_Mysql.php,v 1.5 2006/12/16 19:07:28 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB_Mysql extends SyL_DB
 {
+    /**
+     * 󥳡Ѵơ֥
+     *
+     *  MySQL    <=> PHP
+     *  (client)     (client)
+     * 
+     * ƾʸǵ
+     *
+     * @access protected
+     * @var string
+     */
+    var $encode_table = array(
+      // PHP, DB
+      array('eucjp-win', 'ujis'),
+      array('euc-jp',    'ujis'),
+      array('sjis-win',  'sjis' ),
+      array('sjis',      'sjis'),
+      array('utf-8',     'utf8')
+    );
+
     /**
      * DB³¹
      * 
@@ -67,7 +87,26 @@ class SyL_DB_Mysql extends SyL_DB
             $host .= ':' . $port;
         }
         $this->connection = ($persistent) ? mysql_pconnect($host, $user, $passwd) : mysql_connect($host, $user, $passwd);
-        return (is_resource($this->connection) ? mysql_select_db($dbname, $this->connection) : false);
+        if (is_resource($this->connection) && mysql_select_db($dbname, $this->connection)) {
+            $this->setClientEncoding();
+            return true;
+        } else {
+            return false;
+        }
+    }
+
+    /**
+     * 饤¦ʸ󥳡ƥ
+     * 
+     * @access public
+     * @param string ʸ
+     */
+    function setClientEncoding($client_encode='')
+    {
+        parent::setClientEncoding($client_encode);
+        if ($this->client_encode)
+            @mysql_query("SET NAMES {$this->client_encode}", $this->connection);
+        }
     }
 
     /**
@@ -91,8 +130,11 @@ class SyL_DB_Mysql extends SyL_DB
      */
     function getLastError()
     {
-        $error_message = mysql_error($this->connection);
-        $this->convertDecode($error_message);
+        $error_no = mysql_errno($this->connection);
+        $error_message = '';
+        if ($error_no != 0) {
+            $error_message = "[Error No {$error_no}] " . mysql_error($this->connection);
+        }
         return $error_message;
     }
 
@@ -105,15 +147,7 @@ class SyL_DB_Mysql extends SyL_DB
      */
     function sanitize($parameter)
     {
-        if (!is_numeric($parameter)) {
-            if (function_exists('mysql_real_escape_string')) {
-                return mysql_real_escape_string($parameter, $this->connection);
-            } else {
-                return mysql_escape_string($parameter);
-            }
-        } else {
-            return $parameter;
-        }
+        return !is_numeric($parameter) ? mysql_real_escape_string($parameter, $this->connection) : $parameter;
     }
 
     /**
@@ -135,8 +169,8 @@ class SyL_DB_Mysql extends SyL_DB
      */
     function rollback()
     {
-        @mysql_query('SET AUTOCOMMIT=1', $this->connection);
         @mysql_query('ROLLBACK', $this->connection);
+        @mysql_query('SET AUTOCOMMIT=1', $this->connection);
         parent::rollback();
     }
 
@@ -147,8 +181,8 @@ class SyL_DB_Mysql extends SyL_DB
      */
     function commit()
     {
-        @mysql_query('SET AUTOCOMMIT=1', $this->connection);
         @mysql_query('COMMIT', $this->connection);
+        @mysql_query('SET AUTOCOMMIT=1', $this->connection);
         parent::commit();
     }
 
@@ -161,13 +195,11 @@ class SyL_DB_Mysql extends SyL_DB
      */
     function executeSelect($sql)
     {
-        // ʸɥС
-        $this->convertEncode($sql);
         $result = @mysql_query($sql, $this->connection);
         if ($result !== false) {
             return $result;
         } else {
-            $this->trigger_error_db($this->getLastError());
+            $this->executeTriggerError($this->getLastError());
             return false;
         }
     }
@@ -181,13 +213,11 @@ class SyL_DB_Mysql extends SyL_DB
      */
     function executeUpdate($sql)
     {
-        // ʸɥС
-        $this->convertEncode($sql);
         $result = @mysql_query($sql, $this->connection);
         if ($result !== false) {
             return mysql_affected_rows($this->connection);
         } else {
-            $this->trigger_error_db($this->getLastError());
+            $this->executeTriggerError($this->getLastError());
             return false;
         }
     }
@@ -201,13 +231,11 @@ class SyL_DB_Mysql extends SyL_DB
      */
     function executeNoReturn($sql)
     {
-        // ʸɥС
-        $this->convertEncode($sql);
         $result = @mysql_query($sql, $this->connection);
         if ($result !== false) {
             return true;
         } else {
-            $this->trigger_error_db($this->getLastError());
+            $this->executeTriggerError($this->getLastError());
             return false;
         }
     }
@@ -230,12 +258,8 @@ class SyL_DB_Mysql extends SyL_DB
      */
     function executeGet($sql, &$data, $get='all')
     {
-        // SQL¸
-        $this->setLog($sql);
-        // ʸɥС
-        $this->convertEncode($sql);
         // SQL¹
-        $query = @mysql_query($sql, $this->connection);
+        $this->execute($sql, $query);
     
         // ¹Ի顼Ƚ
         if (is_resource($query)) {
@@ -243,7 +267,6 @@ class SyL_DB_Mysql extends SyL_DB
             case 'one':
                 if (mysql_num_rows($query) > 0) {
                     list($data) = mysql_fetch_row($query);
-                    $this->convertDecode($data);
                 } else {
                     $data = '';
                 }
@@ -254,14 +277,12 @@ class SyL_DB_Mysql extends SyL_DB
                     $data = array();
                 } else {
                     $data = $this->changeFieldName($data);
-                    $this->convertDecode($data);
                 }
                 break;
             case 'all':
                 $data = array();
                 while ($result = mysql_fetch_assoc($query)) {
                     $result = $this->changeFieldName($result);
-                    $this->convertDecode($result);
                     $data[] = $result;
                 }
                 break;
@@ -269,7 +290,7 @@ class SyL_DB_Mysql extends SyL_DB
             mysql_free_result($query);
             return true;
         } else {
-            $this->trigger_error_db($this->getLastError());
+            $this->executeTriggerError($this->getLastError());
             return false;
         }
     }
@@ -290,8 +311,8 @@ class SyL_DB_Mysql extends SyL_DB
     function executePage($sql, &$result, &$page_control, $limit, $page=1)
     {
         // ڡ楯饹
-        include_once dirname(dirname(__FILE__)) . DIRECTORY_SEPARATOR . 'SyL_PageControl.php';
-        $page_control = new SyL_PageControl();
+        include_once dirname(dirname(__FILE__)) . '/SyL_Pager.php';
+        $page_control = new SyL_Pager();
         $page_control->setCount($limit);
         $page_control->setPage($page);
 
@@ -309,44 +330,6 @@ class SyL_DB_Mysql extends SyL_DB
         return $this->executeGet($sql_page, $result, 'all');
     }
 
-    /**
-     * ʸ򥯥饤ʸɤ˥ǥɤ
-     *
-     * @access public
-     * @param string ǥʸ
-     */
-    function convertEncode(&$values)
-    {
-        if ($this->server_encode != $this->client_encode) {
-            if (is_array($values)) {
-                foreach ($values as $key => $value) {
-                    $values[$key] = $this->convertEncode( $values[$key] );
-                }
-            } else {
-                $values = mb_convert_encoding($values, $this->server_encode, $this->client_encode);
-            }
-        }
-    }
-
-    /**
-     * ʸ򥯥饤ʸɤ˥ǥɤ
-     *
-     * @access public
-     * @param string ǥʸ
-     */
-    function convertDecode(&$values)
-    {
-        if ($this->server_encode != $this->client_encode) {
-            if (is_array($values)) {
-                foreach ($values as $key => $value) {
-                    $values[$key] = $this->convertDecode( $values[$key] );
-                }
-            } else {
-                $values = mb_convert_encoding($values, $this->client_encode, $this->server_encode);
-            }
-        }
-    }
-
     /**
      * եեޥåȴؿ̾
      *
