@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.4 2006/12/11 11:59:19 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.5 2006/12/16 19:07:28 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -45,7 +45,7 @@ define( 'DB_DEBUG', false );
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.4 2006/12/11 11:59:19 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.5 2006/12/16 19:07:28 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -72,26 +72,26 @@ class SyL_DB
      */
     var $transaction = false;
     /**
-     * 饤ȥ󥳡
+     * DB饤ȥ󥳡
      * 
      * @access protected
      * @var string
      */
     var $client_encode = '';
     /**
-     * С󥳡
+     * PHP󥳡
      * 
      * @access protected
      * @var string
      */
-    var $server_encode = '';
+    var $php_encode = '';
     /**
-     * ֥
+     * 󥳡Ѵơ֥
      * 
      * @access protected
-     * @var object
+     * @var string
      */
-    var $log = null;
+    var $encode_table = array();
 
     /**
      * ե򻲾Ȥ
@@ -118,9 +118,16 @@ class SyL_DB
      * ǽ顼å
      * 
      * @access protected
-     * @var string ǽ顼å
+     * @var string
      */
-    var $db_last_error = '';
+    var $last_error = '';
+    /**
+     * Хå᥽å
+     * 
+     * @access protected
+     * @var mixed
+     */
+    var $callback_log = null;
 
     /**
      * 󥹥ȥ饯
@@ -130,12 +137,12 @@ class SyL_DB
      * @param string 饤ȥ󥳡
      * @param string С󥳡
      */
-    function SyL_DB($dbtype, $client_encode, $server_encode)
+    function SyL_DB($dbtype, $client_encode, $php_encode)
     {
         set_magic_quotes_runtime(0);
         $this->dbname = $dbtype;
         $this->client_encode = $client_encode;
-        $this->server_encode = $server_encode;
+        $this->php_encode    = $php_encode;
     }
 
     /**
@@ -144,18 +151,12 @@ class SyL_DB
      * ˡ
      *   $db =& SyL_DB::getInstance();
      *
-     * $dsn = '[dbtype]:dbname=[dbname];host=[hostname];port=[port];user=[username];passwd=[password]';
-     * $options = array(
-     *   'persistent'    => bool,
-     *   'client_encode' => string,
-     *   'server_encode' => string
-     * );
-     *
+     * $dsn = '[dbtype]:dbname=[dbname];host=[hostname];port=[port];user=[username];passwd=[password];client_encode=[client_encode];persistent=[persistent]';
      *
      * @access public
      * @param string ³ʸ
      */
-    function &getConnection($dsn)
+    function &getConnection($dsn, $php_encode='')
     {
         static $singleton = array();
         if (!isset($singleton[$dsn])) {
@@ -168,7 +169,6 @@ class SyL_DB
             $port   = '';
             $persistent    = '';
             $client_encode = '';
-            $server_encode = '';
             if (isset($tmp[1])) {
                 $tmp = explode(';', $tmp[1]);
                 foreach ($tmp as $tmp2) {
@@ -180,7 +180,7 @@ class SyL_DB
             $class_name = 'SyL_DB_' . $dbtype;
             // ¥󥹥󥹺
             include_once dirname(__FILE__) . "/DB/{$class_name}.php";
-            $singleton[$dsn] = new $class_name($dbtype, $client_encode, $server_encode);
+            $singleton[$dsn] = new $class_name($dbtype, $client_encode, $php_encode);
             $singleton[$dsn]->openConnection($dbname, $user, $passwd, $host, $port, $persistent);
         }
         return $singleton[$dsn];
@@ -189,7 +189,7 @@ class SyL_DB
     /**
      * DB³¹
      * 
-     * @access public
+     * @access protected
      * @param string ǡ١̾
      * @param string 桼̾
      * @param string ѥ
@@ -200,7 +200,7 @@ class SyL_DB
      */
     function openConnection($dbname, $user, $passwd, $host, $port, $persistent)
     {
-        trigger_error( "[SyL error] openConnection method not found ({$dbname})", E_USER_ERROR );
+        trigger_error("[SyL error] openConnection method not found ({$dbname})", E_USER_ERROR);
     }
 
     /**
@@ -211,25 +211,33 @@ class SyL_DB
     function closeConnection() {}
 
     /**
-     * 饤¦ʸ󥳡ƥ
+     * DB饤¦ʸ󥳡ƥ
      * 
      * @access public
      * @param string ʸ
      */
-    function setClientEncoding($client_encode)
+    function setClientEncoding($client_encode='')
     {
-        $this->client_encode = $client_encode;
-    }
-
-    /**
-     * С¦ʸ󥳡ƥ
-     * 
-     * @access public
-     * @param string ʸ
-     */
-    function setServerEncoding($server_encode)
-    {
-        $this->server_encode = $server_encode;
+        if ($client_encode) {
+            $this->client_encode = $client_encode;
+        }
+        if ($this->client_encode) {
+            if (!$this->php_encode) {
+                foreach ($this->encode_table as $encode_table) {
+                    if ($encode_table[1] == strtolower($this->client_encode)) {
+                        $this->php_encode = $encode_table[0];
+                        break;
+                    }
+                }
+            }
+        } else if ($this->php_encode) {
+            foreach ($this->encode_table as $encode_table) {
+                if ($encode_table[0] == strtolower($this->php_encode)) {
+                    $this->client_encode = $encode_table[1];
+                    break;
+                }
+            }
+        }
     }
 
     /**
@@ -274,13 +282,12 @@ class SyL_DB
      * ѥ᡼˥̵˽
      * 
      * @access public
-     *
      * @param string ˥оʸ
      * @return string ˥ʸ
      */
     function sanitize($parameter)
     {
-        return (!is_numeric($parameter) ? addslashes($parameter) : $parameter);
+        return !is_numeric($parameter) ? addslashes($parameter) : $parameter;
     }
 
     /**
@@ -292,7 +299,7 @@ class SyL_DB
      */
     function sanitizeLike($parameter)
     {
-        return preg_replace('/(\_|\%)/', '\\\\$1', $parameter);
+        return preg_replace('/(\_|\%)/', '\\\\$1', $this->sanitize($parameter));
     }
 
     /**
@@ -303,7 +310,7 @@ class SyL_DB
     function begin()
     {
         // SQL¸
-        $this->setLog('begin');
+        $this->log('begin');
   
         if (class_exists('SyL_Error')) {
             $e =& SyL_Error::getInstance();
@@ -320,7 +327,7 @@ class SyL_DB
     function rollback()
     {
         // SQL¸
-        $this->setLog('rollback');
+        $this->log('rollback');
 
         if (class_exists('SyL_Error')) {
             $e =& SyL_Error::getInstance();
@@ -337,7 +344,7 @@ class SyL_DB
     function commit()
     {
       // SQL¸
-      $this->setLog('commit');
+      $this->log('commit');
 
       if (class_exists('SyL_Error')) {
           $e =& SyL_Error::getInstance();
@@ -364,7 +371,7 @@ class SyL_DB
     function execute($sql, &$result)
     {
         // SQL¸
-        $this->setLog($sql);
+        $this->log($sql);
 
         // ᥽å̾
         list($method) = explode( ' ', $sql, 2 );
@@ -390,12 +397,11 @@ class SyL_DB
     /**
      * SQL¹ԤDB꥽
      *
-     * @access public
-     *
+     * @access protected
      * @param string SQLʸ
      * @return mixed ¹OK: DB꥽, ¹NG: false
      */
-    function &executeSelect( $sql )
+    function &executeSelect($sql)
     {
         trigger_error("[SyL error] executeSelect method not found ({$dbname})", E_USER_ERROR);
     }
@@ -403,12 +409,11 @@ class SyL_DB
     /**
      * SQL¹Ԥ¹Է̱ƶ
      *
-     * @access public
-     *
+     * @access protected
      * @param string SQLʸ
      * @return mixed ¹OK: ¹Է̱ƶ, ¹NG: false
      */
-    function executeUpdate( $sql )
+    function executeUpdate($sql)
     {
         trigger_error("[SyL error] executeUpdate method not found ({$dbname})", E_USER_ERROR);
     }
@@ -416,12 +421,11 @@ class SyL_DB
     /**
      * SQL¹ԤΤ
      *
-     * @access public
-     *
+     * @access protected
      * @param string SQLʸ
      * @return boolean ¹OK: true, ¹NG: false
      */
-    function executeNoReturn( $sql )
+    function executeNoReturn($sql)
     {
         trigger_error("[SyL error] executeNoReturn method is not found ({$dbname})", E_USER_ERROR);
     }
@@ -443,7 +447,7 @@ class SyL_DB
      * @param string ̼ե饰
      * @return boolean ¹OK: true, ¹NG: false
      */
-    function executeGet( $sql, &$data, $get='all' ) {}
+    function executeGet($sql, &$data, $get='all') {}
 
     /**
      * SQL¹Ԥڡ˥ǡ
@@ -589,10 +593,10 @@ class SyL_DB
      * @access public
      * @param string 顼å
      */
-    function trigger_error_db($error_message)
+    function executeTriggerError($error_message)
     {
         if (($this->transaction) || (!$this->trigger_error_flag)) {
-            $this->db_last_error = $error_message;
+            $this->last_error = $error_message;
         } else {
             trigger_error($error_message, E_USER_ERROR);
         }
@@ -606,7 +610,7 @@ class SyL_DB
      */
     function getLastErrorMessage()
     {
-        return $this->db_last_error;
+        return $this->last_error;
     }
 
     /**
@@ -618,26 +622,52 @@ class SyL_DB
      */
     function changeFieldName($record)
     {
-        if (is_array($record) && ($this->field_ref != '')) {
+        if (is_array($record) && $this->field_ref) {
             return array_change_key_case($record, $this->field_ref);
         } else {
             return $record;
         }
     }
 
+    /**
+     * Хå᥽åɤ򥻥å
+     *
+     * @access public
+     * @param mixed Хå᥽å
+     */
+    function setCallbackLog($callback_log)
+    {
+        if (is_callable($callback_log)) {
+            $this->callback_log = $callback_log;
+        } else {
+            trigger_error("[SyL error] setCallbackLog argument invalid function (" . print_r($callback_log, true) . ")");
+        }
+    }
+
     /**
      * SQL¸
      *
      * @access public
      * @param string SQLʸ
      */
-    function setLog($sql)
+    function log($sql)
     {
-        if (is_object($this->log)) {
-            $this->log->debug($sql);
+        if ($this->callback_log != null) {
+            call_user_func($this->callback_log, $sql);
         }
     }
 
+    /**
+     * Ȥ³꥽
+     *
+     * @access public
+     * @return resource DB³꥽
+     */
+    function &getResourceConnection()
+    {
+        return $this->connection;
+    }
+
     /**
      * DB饹̾
      *
